print.trace_model: Print Trace Model

View source: R/trace_model.R

print.trace_modelR Documentation

Print Trace Model

Description

Print Trace Model

Usage

## S3 method for class 'trace_model'
print(x, ...)

Arguments

x

A trace_model object.

...

Ignored.

Value

Invisibly returns x. Called for its side effect of printing a summary of the trace model (ADaM variable count, SDTM variable count, edge count, orphan count, and ambiguity count) to the console.


r4subtrace documentation built on March 4, 2026, 1:07 a.m.